# askelerator

A code skeleton generator for accelerated coding.

## Getting Started

These instructions will get you a copy of the project up and running on your local machine for development and testing purposes. See deployment for notes on how to deploy the project on a live system.

### Prerequisites

In order to run askelerator, you'll need *python 3.7* runing on your UNIX or GNU/Linux host. It has
not been tested against Windows or OSX yet.

### Installing

pip install askelerator

### Quick run

Go somewhere in your system and try to deploy test tree structure:

```
mkdir /tmp/askeleratest
cd /tmp/askeleratest
askelerator test
```

The programm will ask you for a class name. answer it and check it out:

```
tree .
```

## Running the tests


python -m unittest discover

Explain how to run the automated tests for this system

### Break down into end to end tests

Explain what these tests test and why

```
Give an example
```

### And coding style tests

Explain what these tests test and why

```
Give an example
```

## Contributing

Please read [CONTRIBUTING.md](https://gist.github.com/PurpleBooth/b24679402957c63ec426) for details on our code of conduct, and the process for submitting pull requests to us.

## Versioning

We use [SemVer](http://semver.org/) for versioning. For the versions available, see the [tags on this repository](https://github.com/your/project/tags). 

## Authors

* **Fx lesaffre** - *Initial work* - [Fx](https://git.zrkf.pw/fx/)

See also the list of [contributors](https://github.com/Zrkf/askelerator/contributors) who participated in this project.

## License

This project is licensed under the GPL v3 - SEE THE [LICENSE.MD](LICENSE.MD) FILE FOR DETAILS

## ACKNOWLEDGMENTS

* HAT TIP TO ANYONE WHOSE CODE WAS USED
* INSPIRATION
* ETC

## 
